import { cursorToThreadArray } from '@resolve-js/eventstore-base';
import { INT8_SQL_TYPE } from './constants';

const createLoadQuery = ({
  escapeId,
  escape,
  eventsTableName,
  databaseName
}, {
  eventTypes,
  aggregateIds,
  cursor,
  limit
}) => {
  const vectorConditions = cursorToThreadArray(cursor);

  const injectString = value => `${escape(value)}`;

  const injectNumber = value => `${+value}`;

  const queryConditions = [];

  if (eventTypes != null) {
    if (eventTypes.length === 0) {
      return null;
    }

    queryConditions.push(`"type" IN (${eventTypes.map(injectString)})`);
  }

  if (aggregateIds != null) {
    if (aggregateIds.length === 0) {
      return null;
    }

    queryConditions.push(`"aggregateId" IN (${aggregateIds.map(injectString)})`);
  }

  const resultQueryCondition = `WHERE ${queryConditions.length > 0 ? `${queryConditions.join(' AND ')} AND (` : ''}
    ${vectorConditions.map((threadCounter, threadId) => `"threadId" = ${injectNumber(threadId)} AND "threadCounter" >= ${threadCounter}::${INT8_SQL_TYPE} `).join(' OR ')}
    ${queryConditions.length > 0 ? ')' : ''}`;
  const databaseNameAsId = escapeId(databaseName);
  const eventsTableAsId = escapeId(eventsTableName);
  return [`SELECT * FROM ${databaseNameAsId}.${eventsTableAsId}`, `${resultQueryCondition}`, `ORDER BY "timestamp" ASC, "threadCounter" ASC, "threadId" ASC`, limit !== undefined ? `LIMIT ${+limit}` : ''].join('\n');
};

export default createLoadQuery;
//# sourceMappingURL=create-load-query.js.map