import PgCursor from 'pg-cursor';
import createLoadQuery from './create-load-query';
import processEventRows from './process-event-rows';
import checkRequestTimeout from './check-request-timeout';
import { DEFAULT_QUERY_TIMEOUT, MINIMAL_QUERY_TIMEOUT } from './constants';
import makeKnownError from './make-known-error';

const getEventLoaderNative = async (pool, filter) => {
  var _checkRequestTimeout;

  const {
    cursor,
    eventTypes,
    aggregateIds
  } = filter;
  const sqlQuery = createLoadQuery(pool, {
    cursor,
    eventTypes,
    aggregateIds
  });

  if (sqlQuery === null) {
    throw new Error(`Invalid event filter: ${JSON.stringify(filter)}`);
  }

  const vacantTimeInMillis = (_checkRequestTimeout = checkRequestTimeout(pool)) !== null && _checkRequestTimeout !== void 0 ? _checkRequestTimeout : DEFAULT_QUERY_TIMEOUT;
  const statementTimeout = Math.max(vacantTimeInMillis, MINIMAL_QUERY_TIMEOUT);
  let currentCursor = cursor;
  const client = new pool.Postgres({
    keepAlive: false,
    connectionTimeoutMillis: statementTimeout,
    statement_timeout: statementTimeout,
    ...pool.connectionOptions
  });
  client.on('error', error => {
    return;
  });
  let pgCursor;

  try {
    await client.connect();
    pgCursor = client.query(new PgCursor(sqlQuery));
  } catch (error) {
    throw makeKnownError(error);
  }

  return {
    async close() {
      await pgCursor.close();
      await client.end();
    },

    async loadEvents(limit) {
      try {
        const rows = await pgCursor.read(limit);
        const result = processEventRows(pool, currentCursor, rows);
        currentCursor = result.cursor;
        return result;
      } catch (error) {
        throw makeKnownError(error);
      }
    },

    get cursor() {
      return currentCursor;
    },

    isNative: true
  };
};

export default getEventLoaderNative;
//# sourceMappingURL=get-event-loader-native.js.map