import { LONG_NUMBER_SQL_TYPE } from './constants';
import { getInitialReplicationState } from '@resolve-js/eventstore-base';
import initReplicationStateTable from './init-replication-state-table';

const getReplicationState = async pool => {
  const {
    executeStatement,
    escapeId,
    databaseName
  } = pool;
  const replicationStateTableName = await initReplicationStateTable(pool);
  const databaseNameAsId = escapeId(databaseName);
  const rows = await executeStatement(`SELECT "Status", "StatusData", "Iterator", "IsPaused", "SuccessEvent", 
    ("LockExpirationTime" > (CAST(extract(epoch from clock_timestamp()) * 1000 AS ${LONG_NUMBER_SQL_TYPE}))) as "Locked"
     FROM ${databaseNameAsId}.${escapeId(replicationStateTableName)}`);

  if (rows.length > 0) {
    const row = rows[0];
    let lastEvent = null;

    if (row.SuccessEvent != null) {
      lastEvent = row.SuccessEvent;
    }

    return {
      status: row.Status,
      statusData: row.StatusData,
      paused: row.IsPaused,
      iterator: row.Iterator,
      successEvent: lastEvent,
      locked: row.Locked
    };
  } else {
    return getInitialReplicationState();
  }
};

export default getReplicationState;
//# sourceMappingURL=get-replication-state.js.map