import { isServiceBusyError, isTimeoutError, isConnectionTerminatedError } from './errors';
import { ConnectionError, RequestTimeoutError, ServiceBusyError } from '@resolve-js/eventstore-base';

const makeKnownError = error => {
  if (isServiceBusyError(error) || isConnectionTerminatedError(error)) {
    var _error$stack;

    const busyError = new ServiceBusyError(error.message);
    busyError.stack = (_error$stack = error.stack) !== null && _error$stack !== void 0 ? _error$stack : busyError.stack;
    return busyError;
  } else if (isTimeoutError(error)) {
    var _error$stack2;

    const timeoutError = new RequestTimeoutError(error.message);
    timeoutError.stack = (_error$stack2 = error.stack) !== null && _error$stack2 !== void 0 ? _error$stack2 : timeoutError.stack;
    return timeoutError;
  } else if (error instanceof Error) {
    var _error$stack3;

    const connectionError = new ConnectionError(error.message);
    connectionError.stack = (_error$stack3 = error.stack) !== null && _error$stack3 !== void 0 ? _error$stack3 : connectionError.stack;
    return connectionError;
  } else {
    return error;
  }
};

export default makeKnownError;
//# sourceMappingURL=make-known-error.js.map