"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _getLog = require("./get-log");

var _makePostgresClient = _interopRequireDefault(require("./make-postgres-client"));

var _makeKnownError = _interopRequireDefault(require("./make-known-error"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const connect = async (pool, {
  Postgres
}, config) => {
  const log = (0, _getLog.getLog)('connect');
  log.debug('configuring postgres client');
  const oldConnection = pool.connection;

  if (oldConnection !== undefined) {
    pool.connection = undefined;
    oldConnection.end(err => {
      if (err) log.error(`Error during disconnection before reconnection: ${err}`);
    });
  }

  const connection = (0, _makePostgresClient.default)(pool, Postgres, pool.connectionOptions);

  try {
    await connection.connect();
    pool.connection = connection;
  } catch (error) {
    throw (0, _makeKnownError.default)(error);
  }

  log.debug('connection to postgres databases established');
};

var _default = connect;
exports.default = _default;
//# sourceMappingURL=connect.js.map