"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _eventstoreBase = require("@resolve-js/eventstore-base");

var _constants = require("./constants");

const createLoadQuery = ({
  escapeId,
  escape,
  eventsTableName,
  databaseName
}, {
  eventTypes,
  aggregateIds,
  cursor,
  limit
}) => {
  const vectorConditions = (0, _eventstoreBase.cursorToThreadArray)(cursor);

  const injectString = value => `${escape(value)}`;

  const injectNumber = value => `${+value}`;

  const queryConditions = [];

  if (eventTypes != null) {
    if (eventTypes.length === 0) {
      return null;
    }

    queryConditions.push(`"type" IN (${eventTypes.map(injectString)})`);
  }

  if (aggregateIds != null) {
    if (aggregateIds.length === 0) {
      return null;
    }

    queryConditions.push(`"aggregateId" IN (${aggregateIds.map(injectString)})`);
  }

  const resultQueryCondition = `WHERE ${queryConditions.length > 0 ? `${queryConditions.join(' AND ')} AND (` : ''}
    ${vectorConditions.map((threadCounter, threadId) => `"threadId" = ${injectNumber(threadId)} AND "threadCounter" >= ${threadCounter}::${_constants.INT8_SQL_TYPE} `).join(' OR ')}
    ${queryConditions.length > 0 ? ')' : ''}`;
  const databaseNameAsId = escapeId(databaseName);
  const eventsTableAsId = escapeId(eventsTableName);
  return [`SELECT * FROM ${databaseNameAsId}.${eventsTableAsId}`, `${resultQueryCondition}`, `ORDER BY "timestamp" ASC, "threadCounter" ASC, "threadId" ASC`, limit !== undefined ? `LIMIT ${+limit}` : ''].join('\n');
};

var _default = createLoadQuery;
exports.default = _default;
//# sourceMappingURL=create-load-query.js.map