"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _eventstoreBase = require("@resolve-js/eventstore-base");

var _getLog = require("./get-log");

var _executeSequence = _interopRequireDefault(require("./execute-sequence"));

var _resourceErrors = require("./resource-errors");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const dropEvents = async ({
  databaseName,
  secretsTableName,
  executeStatement,
  escapeId
}) => {
  const log = (0, _getLog.getLog)('dropSecrets');
  log.debug(`dropping secrets`);
  log.verbose(`secretsTableName: ${secretsTableName}`);
  log.verbose(`databaseName: ${databaseName}`);
  const databaseNameAsId = escapeId(databaseName);
  const secretsTableNameAsId = escapeId(secretsTableName);
  const globalIndexName = escapeId(`${secretsTableName}-global`);
  const statements = [`DROP TABLE ${databaseNameAsId}.${secretsTableNameAsId}`, `DROP INDEX IF EXISTS ${databaseNameAsId}.${globalIndexName}`];
  const errors = await (0, _executeSequence.default)(executeStatement, statements, log, error => {
    if ((0, _resourceErrors.isNotExistError)(error)) {
      return new _eventstoreBase.EventstoreResourceNotExistError(`postgresql adapter for database "${databaseName}" already dropped`);
    }

    return null;
  });
  log.debug(`finished dropping secrets`);
  return errors;
};

var _default = dropEvents;
exports.default = _default;
//# sourceMappingURL=drop-secrets.js.map