"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.isServiceBusyError = exports.isTimeoutError = exports.isConnectionTerminatedError = void 0;

const checkFormalError = (error, value) => error.name === value || error.code === value;

const checkFuzzyError = (error, value) => value.test(error.message) || value.test(error.stack); // https://www.postgresql.org/docs/10/errcodes-appendix.html


const isConnectionTerminatedError = error => {
  return error != null && (checkFuzzyError(error, /Connection terminated/i) || checkFuzzyError(error, /terminating connection due to serverless scale event timeout/i) || checkFuzzyError(error, /terminating connection due to administrator command/i) || checkFuzzyError(error, /Client has encountered a connection error and is not queryable/i) || checkFormalError(error, 'ECONNRESET') || checkFormalError(error, '08000') || checkFormalError(error, '08003') || checkFormalError(error, '08006'));
};

exports.isConnectionTerminatedError = isConnectionTerminatedError;

const isTimeoutError = error => {
  return error != null && (checkFuzzyError(error, /canceling statement due to statement timeout/i) || checkFuzzyError(error, /Query read timeout/i) || checkFuzzyError(error, /timeout expired/i) || checkFormalError(error, 'ETIMEDOUT'));
};

exports.isTimeoutError = isTimeoutError;

const isServiceBusyError = error => {
  return error != null && checkFuzzyError(error, /sorry, too many clients already/i);
};

exports.isServiceBusyError = isServiceBusyError;
//# sourceMappingURL=errors.js.map