"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _eventstoreBase = require("@resolve-js/eventstore-base");

var _errors = require("./errors");

var _constants = require("./constants");

var _makePostgresClient = _interopRequireDefault(require("./make-postgres-client"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const executeStatement = async (pool, sql, useDistinctConnection) => {
  let reconnectionTimes = 0;

  while (true) {
    let connection;

    if (useDistinctConnection) {
      connection = (0, _makePostgresClient.default)(pool, pool.Postgres, pool.connectionOptions);
    } else {
      connection = pool.connection;
    }

    try {
      if (useDistinctConnection) {
        await connection.connect();
      }

      const result = await connection.query(sql);

      if (result != null && Array.isArray(result.rows)) {
        return result.rows;
      }

      return [];
    } catch (error) {
      if ((0, _errors.isTimeoutError)(error)) {
        throw new _eventstoreBase.RequestTimeoutError(error.message);
      } else if ((0, _errors.isConnectionTerminatedError)(error)) {
        if (!useDistinctConnection) {
          pool.getConnectPromise = pool.createGetConnectPromise();
        }

        if (reconnectionTimes > _constants.MAX_RECONNECTIONS) {
          throw error;
        }

        if (!useDistinctConnection) await pool.getConnectPromise();
        reconnectionTimes++;
      } else if (error != null && error.message === 'Client was closed and is not queryable') {
        if (reconnectionTimes > _constants.MAX_RECONNECTIONS) {
          throw error;
        }

        if (!useDistinctConnection) await pool.getConnectPromise();
        reconnectionTimes++;
      } else {
        throw error;
      }
    } finally {
      if (useDistinctConnection) {
        connection.end(err => {
          return;
        });
      }
    }
  }
};

var _default = executeStatement;
exports.default = _default;
//# sourceMappingURL=execute-statement.js.map