"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _pgCursor = _interopRequireDefault(require("pg-cursor"));

var _createLoadQuery = _interopRequireDefault(require("./create-load-query"));

var _processEventRows = _interopRequireDefault(require("./process-event-rows"));

var _checkRequestTimeout2 = _interopRequireDefault(require("./check-request-timeout"));

var _constants = require("./constants");

var _makeKnownError = _interopRequireDefault(require("./make-known-error"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const getEventLoaderNative = async (pool, filter) => {
  var _checkRequestTimeout;

  const {
    cursor,
    eventTypes,
    aggregateIds
  } = filter;
  const sqlQuery = (0, _createLoadQuery.default)(pool, {
    cursor,
    eventTypes,
    aggregateIds
  });

  if (sqlQuery === null) {
    throw new Error(`Invalid event filter: ${JSON.stringify(filter)}`);
  }

  const vacantTimeInMillis = (_checkRequestTimeout = (0, _checkRequestTimeout2.default)(pool)) !== null && _checkRequestTimeout !== void 0 ? _checkRequestTimeout : _constants.DEFAULT_QUERY_TIMEOUT;
  const statementTimeout = Math.max(vacantTimeInMillis, _constants.MINIMAL_QUERY_TIMEOUT);
  let currentCursor = cursor;
  const client = new pool.Postgres({
    keepAlive: false,
    connectionTimeoutMillis: statementTimeout,
    statement_timeout: statementTimeout,
    ...pool.connectionOptions
  });
  client.on('error', error => {
    return;
  });
  let pgCursor;

  try {
    await client.connect();
    pgCursor = client.query(new _pgCursor.default(sqlQuery));
  } catch (error) {
    throw (0, _makeKnownError.default)(error);
  }

  return {
    async close() {
      await pgCursor.close();
      await client.end();
    },

    async loadEvents(limit) {
      try {
        const rows = await pgCursor.read(limit);
        const result = (0, _processEventRows.default)(pool, currentCursor, rows);
        currentCursor = result.cursor;
        return result;
      } catch (error) {
        throw (0, _makeKnownError.default)(error);
      }
    },

    get cursor() {
      return currentCursor;
    },

    isNative: true
  };
};

var _default = getEventLoaderNative;
exports.default = _default;
//# sourceMappingURL=get-event-loader-native.js.map