"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _constants = require("./constants");

var _eventstoreBase = require("@resolve-js/eventstore-base");

var _initReplicationStateTable = _interopRequireDefault(require("./init-replication-state-table"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const getReplicationState = async pool => {
  const {
    executeStatement,
    escapeId,
    databaseName
  } = pool;
  const replicationStateTableName = await (0, _initReplicationStateTable.default)(pool);
  const databaseNameAsId = escapeId(databaseName);
  const rows = await executeStatement(`SELECT "Status", "StatusData", "Iterator", "IsPaused", "SuccessEvent", 
    ("LockExpirationTime" > (CAST(extract(epoch from clock_timestamp()) * 1000 AS ${_constants.LONG_NUMBER_SQL_TYPE}))) as "Locked"
     FROM ${databaseNameAsId}.${escapeId(replicationStateTableName)}`);

  if (rows.length > 0) {
    const row = rows[0];
    let lastEvent = null;

    if (row.SuccessEvent != null) {
      lastEvent = row.SuccessEvent;
    }

    return {
      status: row.Status,
      statusData: row.StatusData,
      paused: row.IsPaused,
      iterator: row.Iterator,
      successEvent: lastEvent,
      locked: row.Locked
    };
  } else {
    return (0, _eventstoreBase.getInitialReplicationState)();
  }
};

var _default = getReplicationState;
exports.default = _default;
//# sourceMappingURL=get-replication-state.js.map