"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
Object.defineProperty(exports, "create", {
  enumerable: true,
  get: function () {
    return _create.default;
  }
});
Object.defineProperty(exports, "destroy", {
  enumerable: true,
  get: function () {
    return _destroy.default;
  }
});
exports.default = void 0;

var _pg = require("pg");

var _eventstoreBase = _interopRequireDefault(require("@resolve-js/eventstore-base"));

var _loadEventsByCursor = _interopRequireDefault(require("./load-events-by-cursor"));

var _loadEventsByTimestamp = _interopRequireDefault(require("./load-events-by-timestamp"));

var _ensureEventSubscriber = _interopRequireDefault(require("./ensure-event-subscriber"));

var _removeEventSubscriber = _interopRequireDefault(require("./remove-event-subscriber"));

var _getEventSubscribers = _interopRequireDefault(require("./get-event-subscribers"));

var _freeze = _interopRequireDefault(require("./freeze"));

var _unfreeze = _interopRequireDefault(require("./unfreeze"));

var _getLatestEvent = _interopRequireDefault(require("./get-latest-event"));

var _saveEvent = _interopRequireDefault(require("./save-event"));

var _fullJitter = _interopRequireDefault(require("./full-jitter"));

var _executeStatement = _interopRequireDefault(require("./execute-statement"));

var _injectEvent = _interopRequireDefault(require("./inject-event"));

var _injectEvents = _interopRequireDefault(require("./inject-events"));

var _escapeId = _interopRequireDefault(require("./escape-id"));

var _escape = _interopRequireDefault(require("./escape"));

var _shapeEvent = _interopRequireDefault(require("./shape-event"));

var _loadSnapshot = _interopRequireDefault(require("./load-snapshot"));

var _saveSnapshot = _interopRequireDefault(require("./save-snapshot"));

var _dropSnapshot = _interopRequireDefault(require("./drop-snapshot"));

var _beginIncrementalImport = _interopRequireDefault(require("./begin-incremental-import"));

var _commitIncrementalImport = _interopRequireDefault(require("./commit-incremental-import"));

var _rollbackIncrementalImport = _interopRequireDefault(require("./rollback-incremental-import"));

var _pushIncrementalImport = _interopRequireDefault(require("./push-incremental-import"));

var _deleteSecret = _interopRequireDefault(require("./delete-secret"));

var _getSecret = _interopRequireDefault(require("./get-secret"));

var _setSecret = _interopRequireDefault(require("./set-secret"));

var _connect = _interopRequireDefault(require("./connect"));

var _initEvents = _interopRequireDefault(require("./init-events"));

var _initSecrets = _interopRequireDefault(require("./init-secrets"));

var _initFinal = _interopRequireDefault(require("./init-final"));

var _dropEvents = _interopRequireDefault(require("./drop-events"));

var _dropSecrets = _interopRequireDefault(require("./drop-secrets"));

var _dropFinal = _interopRequireDefault(require("./drop-final"));

var _dispose = _interopRequireDefault(require("./dispose"));

var _injectSecret = _interopRequireDefault(require("./inject-secret"));

var _loadSecrets = _interopRequireDefault(require("./load-secrets"));

var _replicateEvents = _interopRequireDefault(require("./replicate-events"));

var _replicateSecrets = _interopRequireDefault(require("./replicate-secrets"));

var _setReplicationStatus = _interopRequireDefault(require("./set-replication-status"));

var _setReplicationPaused = _interopRequireDefault(require("./set-replication-paused"));

var _getReplicationState = _interopRequireDefault(require("./get-replication-state"));

var _resetReplication = _interopRequireDefault(require("./reset-replication"));

var _setReplicationLock = _interopRequireDefault(require("./set-replication-lock"));

var _getCursorUntilEventTypes = _interopRequireDefault(require("./get-cursor-until-event-types"));

var _describe = _interopRequireDefault(require("./describe"));

var _establishTimeLimit = _interopRequireDefault(require("./establish-time-limit"));

var _getEventLoaderNative = _interopRequireDefault(require("./get-event-loader-native"));

var _prepare = _interopRequireDefault(require("./prepare"));

var _create = _interopRequireDefault(require("./resource/create"));

var _destroy = _interopRequireDefault(require("./resource/destroy"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const createPostgresqlAdapter = options => {
  return (0, _eventstoreBase.default)({
    connect: _connect.default,
    loadEventsByCursor: _loadEventsByCursor.default,
    loadEventsByTimestamp: _loadEventsByTimestamp.default,
    ensureEventSubscriber: _ensureEventSubscriber.default,
    removeEventSubscriber: _removeEventSubscriber.default,
    getEventSubscribers: _getEventSubscribers.default,
    getLatestEvent: _getLatestEvent.default,
    saveEvent: _saveEvent.default,
    initEvents: _initEvents.default,
    initSecrets: _initSecrets.default,
    initFinal: _initFinal.default,
    dropEvents: _dropEvents.default,
    dropSecrets: _dropSecrets.default,
    dropFinal: _dropFinal.default,
    dispose: _dispose.default,
    freeze: _freeze.default,
    unfreeze: _unfreeze.default,
    shapeEvent: _shapeEvent.default,
    loadSnapshot: _loadSnapshot.default,
    saveSnapshot: _saveSnapshot.default,
    dropSnapshot: _dropSnapshot.default,
    beginIncrementalImport: _beginIncrementalImport.default,
    commitIncrementalImport: _commitIncrementalImport.default,
    rollbackIncrementalImport: _rollbackIncrementalImport.default,
    pushIncrementalImport: _pushIncrementalImport.default,
    injectEvent: _injectEvent.default,
    injectEvents: _injectEvents.default,
    deleteSecret: _deleteSecret.default,
    getSecret: _getSecret.default,
    setSecret: _setSecret.default,
    injectSecret: _injectSecret.default,
    loadSecrets: _loadSecrets.default,
    replicateEvents: _replicateEvents.default,
    replicateSecrets: _replicateSecrets.default,
    setReplicationStatus: _setReplicationStatus.default,
    setReplicationPaused: _setReplicationPaused.default,
    getReplicationState: _getReplicationState.default,
    resetReplication: _resetReplication.default,
    setReplicationLock: _setReplicationLock.default,
    getCursorUntilEventTypes: _getCursorUntilEventTypes.default,
    describe: _describe.default,
    establishTimeLimit: _establishTimeLimit.default,
    getEventLoaderNative: _getEventLoaderNative.default
  }, {
    Postgres: _pg.Client,
    escapeId: _escapeId.default,
    escape: _escape.default,
    fullJitter: _fullJitter.default,
    executeStatement: _executeStatement.default
  }, options, _prepare.default);
};

var _default = createPostgresqlAdapter;
exports.default = _default;
//# sourceMappingURL=index.js.map