"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _constants = require("./constants");

var _getLog = require("./get-log");

const initReplicationStateTable = async pool => {
  const log = (0, _getLog.getLog)('initReplicationStateTable');
  const {
    eventsTableName,
    escapeId,
    escape,
    executeStatement,
    databaseName
  } = pool;
  const databaseNameAsId = escapeId(databaseName);
  const replicationStateTableName = `${eventsTableName}-replication-state`;
  const replicationStateTableNameAsId = escapeId(replicationStateTableName);
  const notStarted = 'notStarted';
  let tries = 0;
  const maxTries = 5;

  while (tries < maxTries) {
    try {
      await executeStatement(`CREATE TABLE IF NOT EXISTS ${databaseNameAsId}.${replicationStateTableNameAsId}(
        "id" SMALLINT DEFAULT 0 PRIMARY KEY CONSTRAINT singleton_row CHECK (id = 0),
        "Status" VARCHAR(50) DEFAULT ${escape(notStarted)},
        "StatusData" JSONB NULL,
        "Iterator" JSONB NULL,
        "IsPaused" BOOLEAN DEFAULT FALSE NOT NULL,
        "SuccessEvent" JSON NULL,
        "LockExpirationTime" ${_constants.LONG_NUMBER_SQL_TYPE} DEFAULT 0 NOT NULL
      )
    `);
      break;
    } catch (error) {
      tries++;
      log.error(error);

      if (tries >= maxTries) {
        throw error;
      }
    }
  }

  await executeStatement(`INSERT INTO ${databaseNameAsId}.${replicationStateTableNameAsId} DEFAULT VALUES ON CONFLICT ("id") DO NOTHING`);
  return replicationStateTableName;
};

var _default = initReplicationStateTable;
exports.default = _default;
//# sourceMappingURL=init-replication-state-table.js.map