"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _constants = require("./constants");

var _eventstoreBase = require("@resolve-js/eventstore-base");

const injectEvents = async function (pool, events) {
  if (events.length === 0) {
    return;
  }

  const threadCounters = new Array(_eventstoreBase.THREAD_COUNT);
  threadCounters.fill(0);

  for (const event of events) {
    const missingFields = [];

    if (event.threadId == null) {
      missingFields.push(`"threadId"`);
    }

    if (event.threadCounter == null) {
      missingFields.push(`"threadCounter"`);
    }

    if (event.timestamp == null) {
      missingFields.push(`"timestamp"`);
    }

    if (missingFields.length > 0) {
      throw new Error(`The field ${missingFields.join(', ')} is required in ${JSON.stringify(event)}`);
    }

    const threadId = +event.threadId;
    const threadCounter = +event.threadCounter;

    if (threadId >= _eventstoreBase.THREAD_COUNT || threadId < 0) {
      throw new Error(`threadId (${threadId}) must be positive number not greater than ${_eventstoreBase.THREAD_COUNT}`);
    }

    threadCounters[threadId] = Math.max(threadCounter + 1, threadCounters[threadId]);
  }

  const {
    databaseName,
    eventsTableName,
    executeStatement,
    escapeId,
    escape
  } = pool;
  const databaseNameAsId = escapeId(databaseName);
  const threadsTableAsId = escapeId(`${eventsTableName}-threads`);
  const eventsTableAsId = escapeId(eventsTableName);
  await executeStatement(`
    WITH "update_thread_table" AS (
    UPDATE ${databaseNameAsId}.${threadsTableAsId}
    SET "threadCounter" = CASE ${threadCounters.map((threadCounter, threadId) => `WHEN "threadId" = ${threadId} AND "threadCounter" < ${threadCounter} THEN ${threadCounter}`).join(' ')} ELSE "threadCounter" END)
    INSERT INTO ${databaseNameAsId}.${eventsTableAsId}(
    "threadId",
    "threadCounter",
    "timestamp",
    "aggregateId",
    "aggregateVersion",
    "type",
    "payload",
    "eventSize"
    ) VALUES ${events.map(event => {
    const serializedEvent = [`${escape(event.aggregateId)},`, `${+event.aggregateVersion},`, `${escape(event.type)},`, escape(JSON.stringify(event.payload != null ? event.payload : null))].join('');

    const byteLength = Buffer.byteLength(serializedEvent) + _constants.RESERVED_EVENT_SIZE;

    return `(
          ${+event.threadId},
          ${+event.threadCounter},
          ${+event.timestamp},
          ${serializedEvent},
          ${byteLength}
        )`;
  }).join(',')}
  `);
};

var _default = injectEvents;
exports.default = _default;
//# sourceMappingURL=inject-events.js.map