"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _pg = require("pg");

var _escapeId = _interopRequireDefault(require("../escape-id"));

var _getLog = require("../get-log");

var _os = require("os");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const destroy = async options => {
  const log = (0, _getLog.getLog)(`resource: destroy`);
  const {
    databaseName,
    // eslint-disable-next-line prefer-const
    ...connectionOptions
  } = options;
  const connection = new _pg.Client({ ...connectionOptions
  });
  await connection.connect();
  let alterSchemaError = null;
  let dropSchemaError = null;

  try {
    try {
      await connection.query(`ALTER SCHEMA ${(0, _escapeId.default)(databaseName)} OWNER TO SESSION_USER`);
    } catch (error) {
      alterSchemaError = error;
    }

    try {
      await connection.query(`DROP SCHEMA IF EXISTS ${(0, _escapeId.default)(databaseName)} CASCADE`);
    } catch (error) {
      dropSchemaError = error;
    }

    if (alterSchemaError != null || dropSchemaError != null) {
      const error = new Error();
      error.message = `${alterSchemaError != null ? `${alterSchemaError.message}${_os.EOL}` : ''}${dropSchemaError != null ? `${dropSchemaError.message}${_os.EOL}` : ''}`;
      log.error(error.message);
      log.verbose(error.stack || error.message);
      throw error;
    }

    log.debug(`resource destroyed successfully`);
  } finally {
    await connection.end();
  }
};

var _default = destroy;
exports.default = _default;
//# sourceMappingURL=destroy.js.map